@@ -2,7 +2,7 @@ package Net::DNS::RR::MB;
 
 use strict;
 use warnings;
-our $VERSION = (qw$Id: MB.pm 1857 2021-12-07 13:38:02Z willem $)[2];
+our $VERSION = (qw$Id: MB.pm 1910 2023-03-30 19:16:30Z willem $)[2];
 
 use base qw(Net::DNS::RR);
 
@@ -19,41 +19,38 @@ use Net::DNS::DomainName;
 
 
 sub _decode_rdata {			## decode rdata from wire-format octet string
-	my $self = shift;
+	my ( $self, @argument ) = @_;
 
-	$self->{madname} = Net::DNS::DomainName1035->decode(@_);
+	$self->{madname} = Net::DNS::DomainName1035->decode(@argument);
 	return;
 }
 
 
 sub _encode_rdata {			## encode rdata as wire-format octet string
-	my $self = shift;
+	my ( $self, @argument ) = @_;
 
-	my $madname = $self->{madname} || return '';
-	return $madname->encode(@_);
+	return $self->{madname}->encode(@argument);
 }
 
 
 sub _format_rdata {			## format rdata portion of RR string.
 	my $self = shift;
 
-	my $madname = $self->{madname} || return '';
-	return $madname->string;
+	return $self->{madname}->string;
 }
 
 
 sub _parse_rdata {			## populate RR from rdata in argument list
-	my $self = shift;
+	my ( $self, @argument ) = @_;
 
-	$self->madname(shift);
+	$self->madname(@argument);
 	return;
 }
 
 
 sub madname {
-	my $self = shift;
-
-	$self->{madname} = Net::DNS::DomainName1035->new(shift) if scalar @_;
+	my ( $self, @value ) = @_;
+	for (@value) { $self->{madname} = Net::DNS::DomainName1035->new($_) }
 	return $self->{madname} ? $self->{madname}->name : undef;
 }
 
@@ -120,6 +117,7 @@ DEALINGS IN THE SOFTWARE.
 
 =head1 SEE ALSO
 
-L<perl>, L<Net::DNS>, L<Net::DNS::RR>, RFC1035 Section 3.3.3
+L<perl> L<Net::DNS> L<Net::DNS::RR>
+L<RFC1035(3.3.3)|https://tools.ietf.org/html/rfc1035>
 
 =cut
